@@ -13,7 +13,7 @@ import os
 import dj_database_url
 
 
-# The name of this site.  Used for branding in the online admin area.
+# The name and domain of this site.
 
 SITE_NAME = "Example"
 
@@ -57,7 +57,7 @@ AWS_S3_SECURE_URLS = False
 
 AWS_REDUCED_REDUNDANCY = False
 
-AWS_IS_GZIPPED = True
+AWS_IS_GZIPPED = False
 
 
 # Email settings.
